@@ -7,6 +7,7 @@ Pipeline helper class to create pipelines loading modules from a flexible manife
 import argparse
 from collections import defaultdict
 import os
+import sys
 import json
 import logging
 import re
@@ -212,6 +213,57 @@ class AMLPipelineHelper:
             )
         return True
 
+    @staticmethod
+    def validate_connection_attribute(connection_attribute, connection_attribute_type):
+        """
+        Function that will verify whether the given connection_attribute (Workspace name, RG name, or Subscription Id) matches the constraints on length, allowed characters, etc...
+        """
+
+        # initialize min_length and max_length
+        min_length = 0
+        max_length = sys.maxsize
+
+        # populate the constraints based on connection_attribute_type
+        if connection_attribute_type == "workspace":
+            min_length = 3
+            max_length = 33
+            # from https://docs.microsoft.com/en-us/azure/templates/microsoft.machinelearningservices/workspaces?tabs=bicep#workspaces
+            connection_attribute_type_constraints = (
+                "only alphanumeric characters and hyphens"
+            )
+            regex_target = "^[a-zA-Z0-9-]*$"
+        elif connection_attribute_type == "resource_group":
+            # from https://docs.microsoft.com/en-us/azure/azure-resource-manager/management/resource-name-rules#microsoftresources
+            connection_attribute_type_constraints = "alphanumeric, underscore, parentheses, hyphen, period (except at end), and Unicode characters that match the allowed characters"
+            regex_target = "^[-\w\._\(\)]+[-\w_\(\)]$"
+        elif connection_attribute_type == "subscription_id":
+            # can't find an official link for this...
+            connection_attribute_type_constraints = "V4 GUID"
+            # following regex taken from: https://stackoverflow.com/questions/19989481/how-to-determine-if-a-string-is-a-valid-v4-uuid
+            regex_target = "^[0-9A-Fa-f]{8}-[0-9A-Fa-f]{4}-4[0-9A-Fa-f]{3}-[89ABab][0-9A-Fa-f]{3}-[0-9A-Fa-f]{12}$"
+        else:
+            regex_target = ""
+            connection_attribute_type_constraints = ""
+            raise ValueError(
+                "connection_attribute_type must be one of 'workspace', 'resource_group', or 'subscription_id'"
+            )
+
+        # check the length first
+        if (len(connection_attribute) < min_length) or (
+            len(connection_attribute) > max_length
+        ):
+            raise ValueError(
+                f"{connection_attribute} must be between {min_length} and {max_length} characters."
+            )
+
+        # check whether the regex matches
+        if not re.match(regex_target, connection_attribute):
+            raise ValueError(
+                f"Valid {connection_attribute_type} names have the following constraints: {connection_attribute_type_constraints}"
+            )
+
+        return True
+
     def is_eyesoff(self) -> bool:
         """ "
         Check whether the workspace is eyes-off.
@@ -1603,6 +1655,17 @@ class AMLPipelineHelper:
         # Check whether the experiment name is valid
         self.validate_experiment_name(self.config.run.experiment_name)
 
+        # Check whether the workspace name, resource group name, and subscription id are valid
+        self.validate_connection_attribute(
+            self.config.aml.workspace_name, "workspace"
+        )  # self.config.aml.workspace_name
+        self.validate_connection_attribute(
+            self.config.aml.resource_group, "resource_group"
+        )
+        self.validate_connection_attribute(
+            self.config.aml.subscription_id, "subscription_id"
+        )
+
         self.repository_info = get_repo_info()
         log.info(f"Running from repository: {self.repository_info}")
 
